import { ReactElement, ReactNode } from 'react';
import { AdditionalProps } from '../common.types';
import { NsIconNameType, NsIconProps } from '../icon';
import { Variants } from '../typography';
import { AccordionContentType, AccordionVariantType } from './enums';

export type AccordionItem = {
    allowMultipleExpanded?: boolean;
    type: AccordionContentType;
    id: string;
    content: string | AccordionItem[] | ReactElement | null;
    icon?: NsIconProps;
    title: string | ReactElement;
    isDefaultOpen?: boolean;
};

export type NsAccordionProps = AdditionalProps & {
    invert: boolean;
    level: number;
    variant: AccordionVariantType;
    items?: AccordionItem[];
    isChild?: boolean;
    headerTypographyVariant?: Variants;
    /** NsIcon's icon name to be shown in opened state */
    openedIconName?: NsIconNameType;
    /** NsIcon's icon name to be shown in closed state */
    closedIconName?: NsIconNameType;
    allowMultipleExpanded: boolean;
    showEndIconWhenEmpty?: boolean;
};

type CommonAccordionType = {
    invert: boolean;
    level: number;
    variant: AccordionVariantType;
    content: AccordionItem['content'];
};

export type NsAccordionHeaderProps = AdditionalProps & {
    title: string | ReactNode;
    // eslint-disable-next-line no-unused-vars
    onClick: (...args: any[]) => void;
    /** a flag for the header, based on which header can change properties */
    isOpen: boolean;
    /** NsIcon's icon name to be shown in opened state */
    openedIconName?: NsIconNameType;
    /** NsIcon's icon name to be shown in closed state */
    closedIconName?: NsIconNameType;
    headerTypographyVariant?: Variants;
    startIcon?: NsIconProps;
    showEndIconWhenEmpty?: boolean;
    content: AccordionItem['content'];
} & Pick<CommonAccordionType, 'invert' | 'variant'>;

export type NsCollapseProps = AdditionalProps & {
    isOpen: boolean;
    isChild: boolean;
    allowMultipleExpanded?: boolean;
    type: AccordionContentType;
} & CommonAccordionType;

export type NsToggleSectionProps = AdditionalProps & {
    title: string | ReactNode;
    /** if true, NsToggle is rendered in open state, that collapsible section is visible */
    defaultOpen?: boolean;
    isChild: boolean;
    type: AccordionContentType;
} & Pick<CommonAccordionType, 'invert' | 'variant' | 'content'>;

export type NsAccordionItemProps = AdditionalProps & {
    isOpen: boolean;
    // eslint-disable-next-line no-unused-vars
    toggleOpen(index: number, isOpen: boolean): void;
    title: string | ReactNode;
    headerTypographyVariant?: Variants;
    /** NsIcon's icon name to be shown in opened state */
    openedIconName?: NsIconNameType;
    /** NsIcon's icon name to be shown in closed state */
    closedIconName?: NsIconNameType;
    startIcon?: NsIconProps;
    isChild: boolean;
    type: AccordionContentType;
    allowMultipleExpanded?: boolean;
    showEndIconWhenEmpty?: boolean;
} & CommonAccordionType;
