import React from 'react';
import { render, fireEvent, screen } from '@/test-utils/index';
import { NsAuthDropdown } from './';

describe('NsAuthDropdown', () => {
    const props = {
        signInRedirectLink: '/signIn',
        signUpRedirectLink: '/signUp',
        signInBtnText: 'Sign In',
        signUpLinkText: 'Sign Up',
        signUpLinkPrefixText: 'Do not have an account?',
        titleText: 'Welcome',
    };

    it('1. should render component with title text', () => {
        render(<NsAuthDropdown {...props} />);
        expect(screen.getByText('Welcome')).toBeInTheDocument();
    });

    it('2. should render the sign in button with text', () => {
        render(<NsAuthDropdown {...props} />);
        const authHead = screen.getByTestId('auth-head');
        fireEvent.click(authHead);
        expect(screen.getByTestId('sign-in-btn')).toBeInTheDocument();
        expect(screen.getByTestId('sign-in-btn')).toHaveTextContent(props.signInBtnText);
        expect(screen.getByTestId('signup-link')).toHaveTextContent(props.signUpLinkText);
    });

    it('3. should have the correct href attribute in SignUpLink', () => {
        render(<NsAuthDropdown {...props} />);
        const authHead = screen.getByTestId('auth-head');
        fireEvent.click(authHead);
        const signUpLink = screen.getByTestId('signup-link');
        expect(signUpLink).toHaveAttribute('href', '/signUp');
    });
    it('4. should close dropdown on mouse leave', () => {
        const { container } = render(<NsAuthDropdown {...props} closeOnMouseLeave={true} />);
        const authHead = screen.getByTestId('auth-head');
        fireEvent.click(authHead);
        expect(screen.getByTestId('sign-in-btn')).toHaveTextContent('Sign In');
        const wrapper = container.querySelector('.auth-wrapper');
        if (wrapper) fireEvent.mouseLeave(wrapper);
        expect(container.querySelector('.auth-wrapper')).toBeNull();
    });
    it('5. should not close dropdown on mouse leave', () => {
        const { container } = render(<NsAuthDropdown {...props} closeOnMouseLeave={false} />);
        const authHead = screen.getByTestId('auth-head');
        fireEvent.click(authHead);
        expect(screen.getByTestId('sign-in-btn')).toHaveTextContent('Sign In');
        const wrapper = container.querySelector('.auth-wrapper');
        if (wrapper) fireEvent.mouseLeave(wrapper);
        expect(container.querySelector('.auth-wrapper')).not.toBeNull();
    });
});
