import { render, screen } from '@/test-utils/index';
import { nuskinTheme } from '@nuskin/foundation-theme';
import React from 'react';

import { NsButton } from '../';

const { palette } = nuskinTheme;

describe('<Button />', () => {
    it('1. should render default primary button styles ', () => {
        const text = 'Click Me';
        render(
            <NsButton color="primary" variant="contained">
                {text}
            </NsButton>
        );

        const button = screen.getByText(text);
        expect(button).toBeInTheDocument();
        expect(button).toHaveStyle(`color: ${palette?.primary?.contrastText}`);
        // expect(button).toHaveStyle(`background-color: ${palette?.primary?.buttonState?.pressed}`);
    });
    it('2. should render default secondary button styles', () => {
        const text = 'Click Me';
        render(
            <NsButton color="success" variant="contained" size="large">
                {text}
            </NsButton>
        );

        const button = screen.getByText(text);

        expect(button).toBeInTheDocument();
        expect(button).toHaveStyle(`color: ${palette.success.contrastText}`);
        // expect(button).toHaveStyle(`background-color: ${palette.success.buttonState?.pressed}`);
    });
    it('3. should render outlined success button', () => {
        render(
            <NsButton color="success" variant="outlined" size="large">
                Click Me
            </NsButton>
        );

        const button = screen.getByText('Click Me');
        expect(button).toBeInTheDocument();
        // expect(button).toHaveStyle(`color: ${palette.success.main}`);
    });
    it('4. should render outlined accentColorA button', () => {
        render(
            <NsButton color={'accentColorA' as any} variant="outlined" size="large">
                Click Me
            </NsButton>
        );

        const button = screen.getByText('Click Me');
        expect(button).toBeInTheDocument();
        // expect(button).toHaveStyle(`color: ${palette?.accentColorA?.main}`);
    });
    it('5. should render text button styles', () => {
        const text = 'Click Me';
        render(
            <NsButton color="success" variant="text" size="large">
                {text}
            </NsButton>
        );

        const button = screen.getByText(text);

        expect(button).toBeInTheDocument();
        // expect(button).toHaveStyle(`color: ${palette.success.main}`);
    });
    it('6. iconOnly variant', () => {
        const text = 'Click Me';
        render(
            <NsButton color="success" variant="text" size="large" iconOnly>
                {text}
            </NsButton>
        );

        const button = screen.getByText(text);

        expect(button).toBeInTheDocument();
        // expect(button).toHaveStyle(`color: ${palette.success.main}`);
    });
});
