import React from 'react';
import { render, screen } from '@testing-library/react';
import NsBrandCard from '../NsBrandCard';

describe('NsBrandCard component', () => {
    const props = {
        title: 'ageLOC LumiSpa',
        backgroundImageUrl: 'https://media.nuskin.com/m/3604b5202b0b64c6/webimage-brand-lumispa-optweb.png',
        brandImageUrl: 'https://media.nuskin.com/m/2571a0407433a6e8/webimage-brand-lumispa.png',
        button: {
            showButton: true,
            buttonText: 'Add to Cart',
            buttonVariant: 'outlined' as 'outlined',
            url: '#',
            endIcon: 'cart' as 'cart',
        },
    };

    it('1. renders with correct content and styles', () => {
        render(<NsBrandCard {...props} />);

        const brandCard = screen.getByTestId('brand-card');
        expect(brandCard).toBeInTheDocument();

        const brandTitle = screen.getByText('ageLOC LumiSpa');
        expect(brandTitle).toBeInTheDocument();

        const addToCartButton = screen.getByText('Add to Cart');
        expect(addToCartButton).toBeInTheDocument();
    });

    it('2. does not render brand title when title is not provided', () => {
        const { container } = render(<NsBrandCard {...{ ...props, title: undefined }} />);

        const brandTitle = container.querySelector('.brand-title');
        expect(brandTitle).toBeNull();
    });

    it('3. renders with "Add to Cart" button when button prop is true', () => {
        render(<NsBrandCard {...props} />);

        const addToCartButton = screen.getByText('Add to Cart');
        expect(addToCartButton).toBeInTheDocument();
    });

    it('4. does not render button when button prop is false', () => {
        let updatedProps = { ...props };
        updatedProps.button.showButton = false;
        const { container } = render(<NsBrandCard {...updatedProps} />);

        const addToCartButton = container.querySelector('.cta');
        expect(addToCartButton).toBeNull();
    });

    it('5. renders with correct styles when size is "small"', () => {
        const { container } = render(<NsBrandCard {...props} size="small" />);

        const cardContainer = container.firstChild;
        const nsBgCardElement = cardContainer?.firstChild;
        expect(cardContainer).toHaveStyle(`
          maxWidth: 160px;
        `);
        expect(nsBgCardElement).toHaveStyle(`
          maxWidth: 160px;
          maxHeight: 179px;
        `);
    });

    it('6. renders with correct styles when size is "large"', () => {
        render(<NsBrandCard {...props} size="large" />);
        const cardContainer = screen.getByTestId('brand-card') as HTMLElement;
        const computedStyles = window.getComputedStyle(cardContainer);

        expect(computedStyles.maxWidth).toBe('190px');
    });

    it('7. renders with default styles when size is not provided', () => {
        render(<NsBrandCard {...props} />);
        const cardContainer = screen.getByTestId('brand-card') as HTMLElement;
        const computedStyles = window.getComputedStyle(cardContainer);

        expect(computedStyles.maxWidth).toBe('190px');
    });
});
