import React from 'react';
import { render, screen } from '@testing-library/react';
import NsXLargeCard from '../NsXLargeCard';

describe('NsXLargeCard component', () => {
    const props = {
        title: 'Title',
        subtitle: 'Subtitle',
        backgroundImageUrl: 'https://media.nuskin.com/m/4f5b0aee8fe3ff90/Small-category-makeup.jpg',
        backgroundImageAlt: 'Facial Moisturizers',
        button: {
            showButton: true,
            buttonText: 'Discover more',
            buttonVariant: 'outlined' as 'outlined',
            buttonColor: 'secondary' as 'secondary',
            url: '#',
        },
    };

    it('1. renders with correct content and styles', () => {
        render(<NsXLargeCard {...props} />);

        const xLargeCard = screen.getByTestId('x-large-card');
        expect(xLargeCard).toBeInTheDocument();

        const subtitleElement = screen.getByText('Subtitle');
        expect(subtitleElement).toBeInTheDocument();

        const titleElement = screen.getByText('Title');
        expect(titleElement).toBeInTheDocument();

        const imageElement = screen.getByAltText('Facial Moisturizers');
        expect(imageElement).toBeInTheDocument();

        const linkElement = screen.getByText('Discover more');
        expect(linkElement).toBeInTheDocument();
    });

    it('2. does not render button when button prop is false', () => {
        let updatedProps = { ...props };
        updatedProps.button.showButton = false;
        const { container } = render(<NsXLargeCard {...updatedProps} />);

        const button = container.querySelector('.cta');
        expect(button).toBeNull();
    });
});
