import Box from '@mui/material/Box';
import { styled } from '@nuskin/foundation-theme';
import { ReactNode, useCallback, useRef } from 'react';
import Slider from 'react-slick';

import CarousalControl from './CarousalControl';
import defaultCarousalSettings from './slickSetting';

import 'slick-carousel/slick/slick-theme.css';
import 'slick-carousel/slick/slick.css';

const SlickContainer = styled(Box)(() => {
    return {
        padding: '30px 0 60px',
        '.slick-slide': {
            display: 'flex',
            justifyContent: 'center',
        },
    };
});
interface CarousalProps<T = any> {
    entries: T[];
    renderEntry(entry: T, index: number): ReactNode;
    allEntryLink?: string;
    allEntryLabel?: string;
    settings: any;
    showControlButtons?: boolean;
}

export default function NsCarousal({
    entries,
    renderEntry,
    allEntryLink = '',
    settings,
    allEntryLabel = 'View All',
    showControlButtons = true,
}: CarousalProps) {
    const sliderRef = useRef();
    const prev = useCallback(() => {
        if (sliderRef.current) {
            const slider = sliderRef.current as any;
            slider.slickPrev();
        }
    }, [sliderRef]);
    const next = useCallback(() => {
        if (sliderRef.current) {
            const slider = sliderRef.current as any;
            slider.slickNext();
        }
    }, [sliderRef]);
    return (
        <SlickContainer className="brand-carousal">
            {showControlButtons ? (
                <CarousalControl prev={prev} next={next} viewAllUrl={allEntryLink} viewAllLabel={allEntryLabel} />
            ) : null}
            <Slider {...{ ...defaultCarousalSettings, ...settings }} ref={sliderRef as any}>
                {entries.map((entry, index) => {
                    return renderEntry(entry, index);
                })}
            </Slider>
        </SlickContainer>
    );
}
