import { Box } from '@mui/material';
import { styled } from '@nuskin/foundation-theme';
import { sizeObjectType } from '../types';
import { commonStyles, getPercentArray } from './common';
import { shouldNotForwardPropsWithKeys } from '../../../common/util';

type StyledGridProps = {
    sizes: sizeObjectType;
    gap?: number;
    isFullWidth: boolean;
};
const options = {
    shouldForwardProp: shouldNotForwardPropsWithKeys<StyledGridProps>(['sizes']),
};

/* main wrapper for column control using css grid */
export const StyledGrid = styled(
    Box as any,
    options
)<StyledGridProps>(({ sizes, gap, isFullWidth }: StyledGridProps) => {
    const gridGap = gap ?? '2rem';
    const maxWidth = isFullWidth ? '100%' : '1200px';
    return {
        gap: gridGap,
        ...commonStyles,
        maxWidth,
        display: 'grid',
        /* here we are creating gridTemplateColumns as calc(40% - 20px) calc(40% - 20px), */
        gridTemplateColumns: getPercentArray(sizes.fractions)
            ?.map((fractionPercent) => `calc(${fractionPercent} - 20px)`)
            .join(''),
        justifyContent: 'center',
        '> *': {
            minWidth: '220px',
            width: 'auto !important',
        },
        '.span-2': {
            gridColumn: 'span 2',
        },
    } as any;
});
