import { render, screen } from '@/test-utils/index';
import { NsImage } from '../';

describe('NsImage component', () => {
    it('1. renders', () => {
        const alt = 'test image';
        render(<NsImage src="image.jpg" width={300} height={300} alt={alt} />);
        const imgElement = screen.getByAltText(alt);
        expect(imgElement).toBeInTheDocument();
    });

    it('2. renders with correct src and alt attributes', () => {
        const src = 'image.jpg';
        const alt = 'test image';
        const { getByAltText } = render(<NsImage src={src} alt={alt} />);
        const image = getByAltText(alt);
        expect(image).toHaveAttribute('src', src);
    });

    it('3. renders with width and height if variant is not provided', () => {
        const { getByAltText } = render(<NsImage src="image.jpg" alt="test image" width={300} height={300} />);
        const image = getByAltText('test image');
        expect(image).toHaveAttribute('width', '300');
        expect(image).toHaveAttribute('height', '300');
    });

    it('4. renders with correct width and height based on variant', () => {
        const { getByAltText } = render(<NsImage src="image.jpg" alt="test image" variant="icon" />);
        const image = getByAltText('test image');
        expect(image).toHaveAttribute('width', '60');
        expect(image).toHaveAttribute('height', '60');
    });

    it('5. renders with correct width and height if variant is "fill"', () => {
        const { getByAltText } = render(<NsImage src="image.jpg" alt="test image" variant="fill" />);
        const image = getByAltText('test image');
        expect(image).toHaveAttribute('width', '100%');
        expect(image).toHaveAttribute('height', 'auto');
    });

    it('6. renders with correct width and height if variant is "award"', () => {
        const { getByAltText } = render(<NsImage src="image.jpg" alt="test image" variant="award" />);
        const image = getByAltText('test image');
        expect(image).toHaveAttribute('width', '130');
        expect(image).toHaveAttribute('height', '130');
    });

    it('7. renders with correct width and height if variant is "product"', () => {
        const { getByAltText } = render(<NsImage src="image.jpg" alt="test image" variant="product" />);
        const image = getByAltText('test image');
        expect(image).toHaveAttribute('width', '300');
        expect(image).toHaveAttribute('height', '300');
    });

    it('8. renders with additional props', () => {
        const { getByAltText } = render(<NsImage src="image.jpg" alt="test image" className="custom-image" />);
        const image = getByAltText('test image');
        expect(image).toHaveClass('custom-image');
    });
});
