import { Box } from '@mui/material';
import { styled, nuskinTheme, ColorUtils, FoundationTheme } from '@nuskin/foundation-theme';
import { fieldStateType } from './types.d';

const { isDarkMode } = ColorUtils;
const { colors } = nuskinTheme;

type InputWrapperType = {
    fieldState: fieldStateType;
};

const getInputBorderColor = (
    palette: FoundationTheme.Theme['palette'],
    fieldState: fieldStateType,
    isLight = true
): string => {
    if (fieldState === 'success') {
        return colors.success[40];
    } else if (fieldState === 'error') {
        return isLight ? colors.red[40] : colors.red[20];
    } else {
        return palette?.primary.main ?? '';
    }
};

const InputWrapper = styled(Box)<InputWrapperType>(({ theme, fieldState }) => {
    /* default value added so that unit tests do not fail */
    const { palette = { primary: { main: '', contrastText: '' } } } = theme;
    const isLight = isDarkMode({ theme });
    const inputFocusedBorder = isLight ? colors.accentColorB[20] : colors.accentColorB[30];
    const inputDisabledBg = isLight ? colors.neutral[30] : colors.neutral[70];
    const inputDisabledBorder = isLight ? colors.neutral[60] : colors.neutral[80];
    const inputDisabledColor = isLight ? colors.neutral[60] : colors.primary.black;
    const defaultBg = palette.primary.contrastText;
    const placeholderColor = isLight ? colors.neutral[50] : colors.neutral[60];
    return {
        display: 'flex',
        alignItems: 'center',
        gap: '22px',

        '.MuiTextField-root': {
            background: defaultBg,

            '.MuiInputBase-root': {
                borderRadius: 0,
                ':hover': {
                    fieldset: {
                        border: `1px solid ${inputFocusedBorder}`,
                    },
                },
                '&.Mui-focused': {
                    fieldset: {
                        border: `3px solid ${inputFocusedBorder}`,
                    },
                },
                fieldset: {
                    border: `1px solid ${getInputBorderColor(palette, fieldState, isLight)}`,
                },
                input: {
                    color: palette.primary.main,
                    background: defaultBg,
                    padding: '11px 10px',
                    '::placeholder': {
                        color: placeholderColor,
                    },
                },
                '&.Mui-disabled': {
                    fieldset: {
                        border: `1px solid ${inputDisabledBorder}`,
                    },
                    input: {
                        background: inputDisabledBg,
                        color: inputDisabledColor,
                    },
                },
            },
        },
    };
});

export default InputWrapper;
