import React from 'react';

import Dialog from '@mui/material/Dialog';

import { ModalVariantMap } from './model/NsModalVariantMap';
import { NsModalProps } from './types';

const NsModal = (props: NsModalProps) => {
    const {
        open,
        handleClose,
        header,
        body,
        additionalProps,
        footer,
        statusInfo,
        variant = 'default',
        fullScreen,
    } = props;

    const { className, scrollType = 'paper', ariaLabel } = additionalProps || {};

    const { ariaLabelledby = 'alert-dialog-title', ariaDescribedby = 'alert-dialog-description' } = ariaLabel || {};

    const Component = ModalVariantMap[variant];

    return (
        <Dialog
            data-testid="nsmodal-dialog"
            fullScreen={fullScreen}
            open={open}
            scroll={scrollType}
            onClose={handleClose}
            aria-labelledby={ariaLabelledby}
            aria-describedby={ariaDescribedby}
            className={className}
        >
            <Component {...{ header, handleClose, body, footer, additionalProps, statusInfo, variant, open }} />
        </Dialog>
    );
};

export default NsModal;
