import React, { useCallback, useState } from 'react';
import { LayoutGroup } from 'framer-motion';
import { NavTabContainer } from './NsNavTab.styled';
import { NavDrawer } from './NavDrawer';
import { NsNavTabComponentProps } from './types.d';
import { NavTitles } from './NavTitles';

export const NsNavTabComponent = ({
    tabs,
    className,
    tabTitleClassName,
    showDrawer = true,
}: NsNavTabComponentProps) => {
    const [active, setActive] = useState<string | null>(null);

    const activeTab = tabs?.find((tab) => tab.tabName === active);

    const handleLeave = useCallback(() => {
        setActive(null);
    }, []);

    return (
        <NavTabContainer data-testid="nav-container" className={`${className} ns-nav-tab-component`}>
            <LayoutGroup>
                <div onMouseLeave={handleLeave} data-testid="nav-container-draw" className="p-0 m-0">
                    <NavTitles
                        tabTitleClassName={tabTitleClassName}
                        tabs={tabs}
                        active={active}
                        setActive={setActive}
                    />
                    <NavDrawer active={active} content={activeTab?.tabContent} showDrawer={showDrawer} />
                </div>
            </LayoutGroup>
        </NavTabContainer>
    );
};
