import type { NsTableHeaderProps, Item } from './types';
import React from 'react';
import { TableHead, TableRow, Box, TableCell } from '@mui/material';
import { StyledTableSortLabel, StyledTableLabel } from './NsTable.styled';
import { visuallyHidden } from '@mui/utils';

export default function NsTableHeader(props: NsTableHeaderProps) {
    const { order, orderBy, headCells, onRequestSort } = props;
    const createSortHandler = (property: keyof Item) => (event: React.MouseEvent<unknown>) => {
        onRequestSort(event, property);
    };

    return (
        <TableHead>
            <TableRow>
                {headCells.map((headCell) =>
                    headCell.sortable ? (
                        <TableCell key={headCell.id} sortDirection={orderBy === headCell.id ? order : false}>
                            <StyledTableSortLabel
                                active={orderBy === headCell.id}
                                direction={orderBy === headCell.id ? order : 'asc'}
                                onClick={createSortHandler(headCell.id)}
                            >
                                {headCell.label}
                                {orderBy === headCell.id ? (
                                    <Box component="span" sx={visuallyHidden}>
                                        {order === 'desc' ? 'sorted descending' : 'sorted ascending'}
                                    </Box>
                                ) : null}
                            </StyledTableSortLabel>
                        </TableCell>
                    ) : (
                        <TableCell key={headCell.id} sortDirection={false}>
                            <StyledTableLabel>{headCell.label}</StyledTableLabel>
                        </TableCell>
                    )
                )}
            </TableRow>
        </TableHead>
    );
}
